==> haskell-tamarin-prover-utils-1.6.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-utils
version:              1.6.0
visibility:           public
id:                   tamarin-prover-utils-1.6.0-V8RVs9kt5jHryJ06pfF6j
key:                  tamarin-prover-utils-1.6.0-V8RVs9kt5jHryJ06pfF6j
license:              LicenseRef-GPL
copyright:
    Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018

maintainer:
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

author:
    Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

homepage:             https://tamarin-prover.github.io/
synopsis:             Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

category:             Theorem Provers
abi:                  25bb9d88ad90744fb0d0d5ddd7dfef7a
exposed:              True
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc

hidden-modules:
    Control.Monad.Fresh.Class Control.Monad.Trans.Disj
    Control.Monad.Disj.Class

import-dirs:          /usr/lib/ghc-8.10.2/site-local/tamarin-prover-utils-1.6.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tamarin-prover-utils-1.6.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/tamarin-prover-utils-1.6.0

hs-libraries:         HStamarin-prover-utils-1.6.0-V8RVs9kt5jHryJ06pfF6j
depends:
    SHA-1.6.4.4-E6Jj9ikGKEM9Q5vfpEwBdT base-4.14.1.0
    base64-bytestring-1.2.0.0-QGUQVBvRt835GfxPBh70w binary-0.8.8.0
    blaze-builder-0.4.1.0-G4KXEZbDrFS6c5MmayHGI7 bytestring-0.10.10.0
    containers-0.6.2.1 deepseq-1.4.4.0 dlist-1.0-7DRBYe2fcAcDHXBLqD5Deq
    exceptions-0.10.4 fclabels-2.0.5-Kx3hglr70iPF2SNWsog5iA mtl-2.2.2
    pretty-1.1.3.6 safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    syb-0.7.1-EJn6avnnYqseQTf54r0Yp time-1.9.3 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-utils-1.6.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-utils
version:              1.6.0
visibility:           public
id:                   tamarin-prover-utils-1.6.0-2Xap1aY89maINFhFWbFCW4
key:                  tamarin-prover-utils-1.6.0-2Xap1aY89maINFhFWbFCW4
license:              LicenseRef-GPL
copyright:
    Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018

maintainer:
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

author:
    Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

homepage:             https://tamarin-prover.github.io/
synopsis:             Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

category:             Theorem Provers
abi:                  99305f5d5f65b0ab328c0489150b9980
exposed:              True
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc

hidden-modules:
    Control.Monad.Fresh.Class Control.Monad.Trans.Disj
    Control.Monad.Disj.Class

import-dirs:          /usr/lib/ghc-8.10.2/site-local/tamarin-prover-utils-1.6.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tamarin-prover-utils-1.6.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/tamarin-prover-utils-1.6.0

hs-libraries:         HStamarin-prover-utils-1.6.0-2Xap1aY89maINFhFWbFCW4
depends:
    SHA-1.6.4.4-E6Jj9ikGKEM9Q5vfpEwBdT base-4.14.1.0
    base64-bytestring-1.2.0.1-B2ZqPQ2l7aS69MXBYqVZV1 binary-0.8.8.0
    blaze-builder-0.4.1.0-G4KXEZbDrFS6c5MmayHGI7 bytestring-0.10.10.0
    containers-0.6.2.1 deepseq-1.4.4.0 dlist-1.0-IAJErwwuMVT9Wv2UsESEvq
    exceptions-0.10.4 fclabels-2.0.5-I92LgSJS3NR2Jb2BoxE4se mtl-2.2.2
    pretty-1.1.3.6 safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    syb-0.7.1-EJn6avnnYqseQTf54r0Yp time-1.9.3 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
